@@ -1,7 +1,7 @@
 from .artifact import Artifact
 from .cluster import Cluster
 from .dataset import Dataset, VolumeOptions
-from .deployment import Deployment
+from .deployment import Deployment, AutoscalingDefinition, AutoscalingMetric
 from .experiment import BaseExperiment, MultiNodeExperiment, SingleNodeExperiment, MpiMultiNodeExperiment
 from .hyperparameter import Hyperparameter
 from .job import Job
