@@ -3,7 +3,7 @@ import click
 from gradient.api_sdk import constants
 from gradient.cli import common
 from gradient.cli.cli import cli
-from gradient.cli.cli_types import ChoiceType
+from gradient.cli.cli_types import ChoiceType, json_string
 from gradient.cli.common import validate_comma_split_option, api_key_option, ClickGroup
 from gradient.commands import notebooks
 from gradient.commands.notebooks import GetNotebookMetricsCommand, StreamNotebookMetricsCommand
@@ -25,13 +25,6 @@ def notebook_metrics():
 
 
 @notebooks_group.command("create", help="Create new notebook")
-@click.option(
-    "--clusterId",
-    "cluster_id",
-    type=str,
-    help="Cluster ID",
-    cls=common.GradientOption,
-)
 @click.option(
     "--machineType",
     "machine_type",
@@ -41,17 +34,26 @@ def notebook_metrics():
     cls=common.GradientOption,
 )
 @click.option(
-    "--containerId",
-    "container_id",
-    type=int,
-    help="Container ID",
+    "--container",
+    "container",
+    required=True,
+    type=str,
+    help="Container name",
     cls=common.GradientOption,
 )
 @click.option(
-    "--container",
-    "container",
+    "--projectId",
+    "project_id",
+    required=True,
     type=str,
-    help="Container name",
+    help="Project ID",
+    cls=common.GradientOption,
+)
+@click.option(
+    "--clusterId",
+    "cluster_id",
+    type=str,
+    help="Cluster ID",
     cls=common.GradientOption,
 )
 @click.option(
@@ -112,6 +114,38 @@ def notebook_metrics():
     type=bool,
     cls=common.GradientOption,
 )
+@click.option(
+    "--environment",
+    "environment",
+    type=json_string,
+    help="Environmental variables",
+    cls=common.GradientOption,
+)
+@click.option(
+    "--workspace",
+    "workspace",
+    help="S3 url or git repository. Directory uploads are not yet supported",
+    default="none",
+    cls=common.GradientOption,
+)
+@click.option(
+    "--workspaceRef",
+    "workspace_ref",
+    help="Git commit hash, branch name or tag",
+    cls=common.GradientOption,
+)
+@click.option(
+    "--workspaceUsername",
+    "workspace_username",
+    metavar="<username>",
+    cls=common.GradientOption,
+)
+@click.option(
+    "--workspacePassword",
+    "workspace_password",
+    help="Workspace password",
+    cls=common.GradientOption,
+)
 @click.option(
     "--tag",
     "tags",
@@ -427,6 +461,7 @@ def artifacts():
 @click.option(
     "--id",
     "notebook_id",
+    required=True,
     cls=common.GradientOption,
     help="ID of the notebook",
 )
